@@ -8,7 +8,7 @@ MGHD <- function(data=NULL, gpar0=NULL, G=2, n=10, label =NULL , method="kmeans"
 if( scale==TRUE){
 	data=scale(as.matrix(data))}
     pcol=ncol(data)
-    if (nrow(data)<((G-1)+G*(2*pcol+2+pcol*(pcol-1)/2)))stop('G is too big, number of parameters > n')
+    #if (nrow(data)<((G-1)+G*(2*pcol+2+pcol*(pcol-1)/2)))stop('G is too big, number of parameters > n')
 	if (is.null(data)) stop('data is null')
 	if (nrow(data) == 1) stop('nrow(data) is equal to 1')
 	if (ncol(data) == 1) stop('ncol(data) is equal to 1; This function currently only works with multivariate data p > 1')
